==> win32_Release_v4.0.1_r916.zip: data/scripts/buildings/wall.lua <==
amtaKi  VR;V&I;Og@"C0U
emk8<hhnrz}iGٻcbKͬ«Ƶҷ÷یȯ锳ܵϪ
0W2Fah7KIJk&G7ٻϦCCA/N#F5I@EOF5E7^*Oǰѽю
?!!98&&8

;%%94**8?#ը	9\]!47A$V"K(36iCvvBi\\iBwwAj__hCvvNePPiBttEuY``Q蜉Uҍ=?  8UUaJJaTTbI||K`UUmFssJaWWfVzBBٵԧIkI5boCsQ}]nbe s\ĩ剫/+! mm{W2QcK{WwGnBoBn::?:6*1::%.19NBl00Y_i	\\up }}JppAuUUvwC~|KߢZ%	)	)	zsu!<~\pz
	
iyoջ܃OMξ٫ʮJhOխ

|F%J$W#Q$G3281B'K-ݠ=??8U4Lrb
*7P5AmN']89oԵƲ¥Ư ˢе$,DDaq[lja*'c/_0Cj`jc
l<Zt^嵵O S:Rr!!qmC;;9Ф̩Ϳڮ۩rfcjc1XtT5=t:S#B+Y*742;_0:3:V9M옵	/;XLqLlj|~GEio{idrxҝ[qgkC<1IiB뒲$BHh`DE|Lsڵǳꆄ
:ɽQ{"^X8)]]SQ/zvvpzszmp*Y-_6X?wjf:r([aIη̠ҷֲ&-
l8{WwR41B`  {Wwlb(PpN.+9Q^cFAa2=*ZqIY#	
ɦlXrC6Z?Q6B*+'[g]+cR0qxRKIijYX\;93EEb:.R(z3[<kzT0
xǠ&wzX45+)E$W2ۈvv .BAd!"<~|?Y>JĺР:'НK_^bwzZgG`L &ud'H&@)N6׳]zq68=yjcJ@"AA̴͙(,pqYA_^=M=~\+/F(M?56GG-eIiEJKAH)kCCAs|zmC"F"fsxoG+5߫C:=7xZ_8F!$rpqS5SHMAEG5Z-d)KEټؚŠ))ƿϪ	+dmnLמ텤}{zyUZƪΘOLFL츟uՁԠГɹ;6r敻٪,I-/mcѴش̒6prp'B+L$/ܰܟ$&:}!	֥(Usz똶ۺѴӴ./-P__tĩȼӸ剮k{xV.

/GoF..jj:bTίݻ]2 -@/K.j
̣_ޣƮǯʩհ§$o+%6u~s9$I(X`q>y^}_Rt*]Y}װE+kI`@>FE*H"N_ZcM/EmDlXZmEt>V?Ty/]85A6bgXb,
093;=]mDE1Y<NwcSzY9{i!!?Rg""鏧w}#	
	 t\98DDdb&?fEfy?|yU=?=!*R^rf`ɠξ˿ߣ uW|Tĸ&sUl<'XǼһoo h!+W`hafgfOm8I$)[;3=ǫ;ltpK.B2W%SaLܬ"7X,uqQ-?WV啖2+"+#<	ePPԠ,'H9Ij_t
yRb'&krӡRLe,/׹,EH6ǰZQQRsns˝:냂
sr1sTiCkyY[OIjl@޻ձi@`eBG/7Gcf/Ʈ%_3"41嘼)
z_W836F,)NjN̬z*G㇥EaH0}ů,H%"dhAq^y!h͢ό:	J$trh3:1?lܐLLcEm.
ðڸʯΥwSʥ+7#yPZS;q67ODka#X^ܳĪY[t5&$pqI>PxմʂsûٴլޭУ⌠Օ^~nDű2Ged9߼9iKm$<9TyYhLV}UH`ScQ޹ܨҧ
oY	
!4H|^_\/F+[7R`8>3/?HlO>YJoH6vvT74
2p"Ws2a` o[7!V&'CF.'6JHd ұо˃4mDc@,$QuTs[>[wrSYrJO?悢MLrnE謭NfZZ9uE ζpv_cw_w^[5Z.l ogEZ_blk
fDPtW쟳.j $Dh/@2[#&6ܹ߰§c;ٱRtmBA2ws~\%%9ӿǄˤܥ˫Ǧ՗҂ηnRurgcOlɄۘJyZzZm8vvS/*	=>帜<}CjҖɱ䌮燘`ad6S0Y<J/\z{.'.>8b9ì؈HT4hFHBChHy$PZڲnX9}Ф<?OO2\ݡ7=씕U("^WV>W;^rK3	
	t	/ckf'[*,GgLٛ񧉹e
[r<1Fk;{)	 3Gd{kiDiI Ft^Pwl
##"0{xMn&b7R|X/V%-vFP4a5*tM:QSsbOT}O'(ibJnIk!}]3hR;pX8qTC5w>;R<~ks%I§Jl<Im`;5l|6B
 lj'ʦ[ѵ1ܮ˿~Tѯ@IoSoMʦ\Oj79
%Nz{U8Y!ͪϻ>)N2(aC鑹TsUnA3V"ʭȼڵǻlni[v&
>6/,n#JlBxiJ0 6!!*4ddkLA@zX2-) `yᒌй4?Ƞu"A8TQc
fAÕӼ΀Mo!ftVu\dJ&ABamO+!!Sw36֫7" }镹^CUdDEÿѴ膮J;ao #ɉk	* 11#
&ѴE>S)]yu
*Uln^{}Z#S<\(:JA⑴U>GK.^BbeEF90(27wtT]%'ZAd۫\_j/-C7#
cY}=s[M(20gA	R;fhRyhOxཕzZR6Y~
yvnѷŠӻ5?{4x|\XnHhc$|}+'홓ˉI
o͞ץH
K/KhH)E`"\3Glvy斚IJnçO;=NO;B2Wu	[(~mLkVM`M-뛙ߦ䁩U\{ʯܳƴײ,`bГ?Ҫ7"iObӶ4󃉰ϼztSGD|uyYX(/߬?-L!uAb|WT >ӫy[NsT`Yg/SjJKgGZk? Z6^:?xdU*'p+
r?O	ՊiYqI'
(䍿ncA1ggO`01x6%%e"*##shrZxZ8\5oGF/@.%)OL5\\(wY--*_?,PPuh+/
 +omf%ѭ+  #	80 ] ~٬ptSzM5yjM]PwP1I9tsdcB/߆ĥףƴR>å*OtSomEas>_']TV,M W2S0X=Yy|)И-驻2,y
$:
	lS2B
(0e(TИ	=0r^ p[W"FqqpJ$m	e $ȟϻq]2o׬¬ʥbt,ݵ
T&I>SQc~ceI64U1Us]8[/
СY0~tqqQzrxq%-~V
}Lo\t)#"m?[ޖ؂^,h/vD`˯ܸ66+GEp'.'.t:^}^>r*V\yajN(104LzK{Sqe^| shD>W7cyqWv1I!W_]s,K*Ge	!\{]c@ûD~3__rZqڭ۳ê NaL)5Fl88;2䜔LyMΊ]c\tWͮNj

.N&55{,%+|Sټ4
ml>[*_6E,X=oa6r.RuݾյX9`_Yb/2'|xcJ,)
;:msۡ\mʪ0%tq;&)EyxXxqxҼɤrpTlZamvD6S%@2Q4)	8UWz!#/,:7O4۷OLkȽs70x}	^^WpjXW{SSXܠ:׽+;O:1{tSOOۓ[HR_
\#RP|5s[##ֶï /c_Wa1Q7#޶,8펤ptSo-]|HBg#>$հ-hK;66<5EnCiDiDdGY{霾n̢凣ΠܔӼȼӾx;Hk礀MHjji
aEcnd&mXTP䔢6z}Hmxyw_tQAtVյੇ\j:lN(,ddB&ssl3& /H:U N*uB%W2W92Hk<Oa̙֚&<>zi&#ϳϝF.*{
(Qڨڵ±넦IMLgxW}~{P@C`DcDHNjU񍌯P~utun	aC6		)=12DA~R0xR"&v[:S51U)hQlJ9;/r%!7WUw.2%GkKoC>'ɺQ7T8RG2κ߭ĥamy8񕲞X8+WҽԻbqU숦sLPU{"	)7 5Sq]hx >LI=2VzQԏ`sD(0B\\(kLDߖx
~AQ_kiG{͹HSןaT
jvSK?]z[[	
!Moť|\PĽݮ蔻ŠhyN(
Ȥ^qyT'zqY (^?S&Ccd3ӡz}	+1)Tp:!Qcpebk`w~*K;K.J*-)~UUwL#Ql*蘵%͙Mu^$z=ioKX~0۵iUhO)eeLhUrkɺ;QbN'# +:8Q"kl|~wAuY^n::rtVҒ99Uѹۮî׃6FLkРglKKDg笃a'ӼŲܮ~qp$HHkXXtHIlKoUOE=?SS?UrR d	efLs
`CdiCI
y{Tᅵ&' 2f_}%h܋j#
HIo>#`Hxg@d-F]n
.~]eKnb^|~Y{3:gBf6~gTw,Hk93\.,tVegza>GTiMQvux
$]q-$jd@<kwU! HG@v;CmA
-
ak[sQKc@L`juES/%o@ѾᙛLD蘺!(2\}_}75U&!JD`?d@uF.!.닗C'Z쀁fW.>=.v$0BCakAmLvOh[C_n>:;X9W%Mݶ΁oc@RאaoK3ļN^[MiߛP^>1^^}[{[6
.Qf<Av4&wcfBLKǽęoKpU0puF񼗷.v1A6ݽcA״۩!Ge9NҮ;i	v\@#ѩ͈fvr])T|rY<1AO76&'+;Gb;sSHȑ$b}׷8{vyYp $THJ
Km	,? "
(KYFdv4	3kj@\]nnOnC/-	cgD9u;2+ahMyq</Ƌ=/
%;S}YJrqW$0|b45
vd2 H]w(]
_^ld1. (D,WSlvx5u0ilDPXKV}9=ii8 q_t_;8\]u		1a`ccNZBQ&M>W3 {^69IXyQx]}kKikAM	0̂.5ӧ!c7_6FIO'z:;w(X[r71DEC{Lw_⚽BqY
 @BqE]}lTt"n^~RBAG2\0_>ZwXOk(8=L~mQ|la]Y:*%@4Qu1QvBCe	mO?$
hxmhLL?Geԗ;ަ5|_/мӼر포ݺrtEشղؾҳԧڊؑŀߙՔӌ؝ŚܕٍȚŋΏݘ˟̋Κ: ܴ{YupUtPx<,ѽAB."Y]AeRUBmuCrpRPvO5̰6($!w #]u5޾aÕꄧۛvNma"
͹ܪry־Ε X %露N1ϳv.NKzt</23V5][|3c -	ѯ˪ɢհѧ⁑$l{㍮!H;5$mJ)
fz	 !:憫~V'&PQ5hhEgycEu;/"ĥɢm{o4v$ 񅄨g@˿t'h3!AqU]FnG9+#K[ï<N`psR*yUIBҦ_M.ZPfSGE`r7(=κߧk;bnD߫ζeU{ߎjbIyWBkۿx^:t5w-FD!
 ("&T1B6Y+Nhrکxz\ȗX8.
 XpdlG[XMHJl,&&5e6jC.ޢ8=5 h.=gaiO2: 
bbV@\o_pU=6NݴǈqpQ
mP񪇧Ʒ遑eؼC@nx_79bȦһַ÷s~S~uU;T H!O("G)M\\\

==> win32_Release_v4.0.2_r965.zip: data/scripts/buildings/wall.lua <==
amtaQi  VR;V&I;Og@"C0U
emk8<hhnrz}iGٻcbKͬ«Ƶҷ÷یȯ锳ܵϪ
0W2Fah7KIJk&G7ٻϦCCA/N#F5I@EOF5E7^*Oǰѽю
?!!98&&8

;%%94**8?#ը	9\]!47A$V"K(36iCvvBi\\iBwwAj__hCvvNePPiBttEuY``Q蜉Uҍ=?  8UUaJJaTTbI||K`UUmFssJaWWfVzBBٵԧIkI5boCsQ}]nbe s\ĩ剫/+! mm{W2QcK{WwGnBoBn::?:6*1::%.19NBl00Y_i	\\up }}JppAuUUvwC~|KߢZ%	)	)	zsu!<~\pz
	
iyoջ܃OMξ٫ʮJhOխ

|F%J$W#Q$G3281B'K-ݠ=??8U4Lrb
*7P5AmN']89oԵƲ¥Ư ˢе$,DDaq[lja*'c/_0Cj`jc
l<Zt^嵵O S:Rr!!qmC;;9Ф̩Ϳڮ۩rfcjc1XtT5=t:S#B+Y*742;_0:3:V9M옵	/;XLqLlj|~GEio{idrxҝ[qgkC<1IiB뒲$BHh`DE|Lsڵǳꆄ
:ɽQ{"^X8)]]SQ/zvvpzszmp*Y-_6X?wjf:r([aIη̠ҷֲ&-
l8{WwR41B`  {Wwlb(PpN.+9Q^cFAa2=*ZqIY#	
ɦlXrC6Z?Q6B*+'[g]+cR0qxRKIijYX\;93EEb:.R(z3[<kzT0
xǠ&wzX45+)E$W2ۈvv .BAd!"<~|?Y>JĺР:'НK_^bwzZgG`L &ud'H&@)N6׳]zq68=yjcJ@"AA̴͙(,pqYA_^=M=~\+/F(M?56GG-eIiEJKAH)kCCAs|zmC"F"fsxoG+5߫C:=7xZ_8F!$rpqS5SHMAEG5Z-d)KEټؚŠ))ƿϪ	+dmnLמ텤}{zyUZƪΘOLFL츟uՁԠГɹ;6r敻٪,I-/mcѴش̒6prp'B+L$/ܰܟ$&:}!	֥(Usz똶ۺѴӴ./-P__tĩȼӸ剮k{xV.

/GoF..jj:bTίݻ]2 -@/K.j
̣_ޣƮǯʩհ§$o+%6u~s9$I(X`q>y^}_Rt*]Y}װE+kI`@>FE*H"N_ZcM/EmDlXZmEt>V?Ty/]85A6bgXb,
093;=]mDE1Y<NwcSzY9{i!!?Rg""鏧w}#	
	 t\98DDdb&?fEfy?|yU=?=!*R^rf`ɠξ˿ߣ uW|Tĸ&sUl<'XǼһoo h!+W`hafgfOm8I$)[;3=ǫ;ltpK.B2W%SaLܬ"7X,uqQ-?WV啖2+"+#<	ePPԠ,'H9Ij_t
yRb'&krӡRLe,/׹,EH6ǰZQQRsns˝:냂
sr1sTiCkyY[OIjl@޻ձi@`eBG/7Gcf/Ʈ%_3"41嘼)
z_W836F,)NjN̬z*G㇥EaH0}ů,H%"dhAq^y!h͢ό:	J$trh3:1?lܐLLcEm.
ðڸʯΥwSʥ+7#yPZS;q67ODka#X^ܳĪY[t5&$pqI>PxմʂsûٴլޭУ⌠Օ^~nDű2Ged9߼9iKm$<9TyYhLV}UH`ScQ޹ܨҧ
oY	
!4H|^_\/F+[7R`8>3/?HlO>YJoH6vvT74
2p"Ws2a` o[7!V&'CF.'6JHd ұо˃4mDc@,$QuTs[>[wrSYrJO?悢MLrnE謭NfZZ9uE ζpv_cw_w^[5Z.l ogEZ_blk
fDPtW쟳.j $Dh/@2[#&6ܹ߰§c;ٱRtmBA2ws~\%%9ӿǄˤܥ˫Ǧ՗҂ηnRurgcOlɄۘJyZzZm8vvS/*	=>帜<}CjҖɱ䌮燘`ad6S0Y<J/\z{.'.>8b9ì؈HT4hFHBChHy$PZڲnX9}Ф<?OO2\ݡ7=씕U("^WV>W;^rK3	
	t	/ckf'[*,GgLٛ񧉹e
[r<1Fk;{)	 3Gd{kiDiI Ft^Pwl
##"0{xMn&b7R|X/V%-vFP4a5*tM:QSsbOT}O'(ibJnIk!}]3hR;pX8qTC5w>;R<~ks%I§Jl<Im`;5l|6B
 lj'ʦ[ѵ1ܮ˿~Tѯ@IoSoMʦ\Oj79
%Nz{U8Y!ͪϻ>)N2(aC鑹TsUnA3V"ʭȼڵǻlni[v&
>6/,n#JlBxiJ0 6!!*4ddkLA@zX2-) `yᒌй4?Ƞu"A8TQc
fAÕӼ΀Mo!ftVu\dJ&ABamO+!!Sw36֫7" }镹^CUdDEÿѴ膮J;ao #ɉk	* 11#
&ѴE>S)]yu
*Uln^{}Z#S<\(:JA⑴U>GK.^BbeEF90(27wtT]%'ZAd۫\_j/-C7#
cY}=s[M(20gA	R;fhRyhOxཕzZR6Y~
yvnѷŠӻ5?{4x|\XnHhc$|}+'홓ˉI
o͞ץH
K/KhH)E`"\3Glvy斚IJnçO;=NO;B2Wu	[(~mLkVM`M-뛙ߦ䁩U\{ʯܳƴײ,`bГ?Ҫ7"iObӶ4󃉰ϼztSGD|uyYX(/߬?-L!uAb|WT >ӫy[NsT`Yg/SjJKgGZk? Z6^:?xdU*'p+
r?O	ՊiYqI'
(䍿ncA1ggO`01x6%%e"*##shrZxZ8\5oGF/@.%)OL5\\(wY--*_?,PPuh+/
 +omf%ѭ+  #	80 ] ~٬ptSzM5yjM]PwP1I9tsdcB/߆ĥףƴR>å*OtSomEas>_']TV,M W2S0X=Yy|)И-驻2,y
$:
	lS2B
(0e(TИ	=0r^ p[W"FqqpJ$m	e $ȟϻq]2o׬¬ʥbt,ݵ
T&I>SQc~ceI64U1Us]8[/
СY0~tqqQzrxq%-~V
}Lo\t)#"m?[ޖ؂^,h/vD`˯ܸ66+GEp'.'.t:^}^>r*V\yajN(104LzK{Sqe^| shD>W7cyqWv1I!W_]s,K*Ge	!\{]c@ûD~3__rZqڭ۳ê NaL)5Fl88;2䜔LyMΊ]c\tWͮNj

.N&55{,%+|Sټ4
ml>[*_6E,X=oa6r.RuݾյX9`_Yb/2'|xcJ,)
;:msۡ\mʪ0%tq;&)EyxXxqxҼɤrpTlZamvD6S%@2Q4)	8UWz!#/,:7O4۷OLkȽs70x}	^^WpjXW{SSXܠ:׽+;O:1{tSOOۓ[HR_
\#RP|5s[##ֶï /c_Wa1Q7#޶,8펤ptSo-]|HBg#>$հ-hK;66<5EnCiDiDdGY{霾n̢凣ΠܔӼȼӾx;Hk礀MHjji
aEcnd&mXTP䔢6z}Hmxyw_tQAtVյੇ\j:lN(,ddB&ssl3& /H:U N*uB%W2W92Hk<Oa̙֚&<>zi&#ϳϝF.*{
(Qڨڵ±넦IMLgxW}~{P@C`DcDHNjU񍌯P~utun	aC6		)=12DA~R0xR"&v[:S51U)hQlJ9;/r%!7WUw.2%GkKoC>'ɺQ7T8RG2κ߭ĥamy8񕲞X8+WҽԻbqU숦sLPU{"	)7 5Sq]hx >LI=2VzQԏ`sD(0B\\(kLDߖx
~AQ_kiG{͹HSןaT
jvSK?]z[[	
!Moť|\PĽݮ蔻ŠhyN(
Ȥ^qyT'zqY (^?S&Ccd3ӡz}	+1)Tp:!Qcpebi
bu|(I9I,H`7c5pR;Y*$ZZt=^|*Rhe}٢S60|?M26֙9yEx_6]]tHuR{٪厜۰,IvٰÊ䍝aWcOHx,,
0\ZiemC[ۿʧʳ熤Hj7䄌;0 #זףegmd,/@29NO Rr
~\Ɗ@nVad@g7ݱ *VR8/ }W]ὕљȰga8ٱJKl}v^2)Y S4qpV70,0ѪiAqnIu<WL	'wvT*+5=50ꊦa2A{kn߷"fM{蔨.:pzgGe=sjyO6%</,H!S}(DtVZZ
:KhJFU)+`mǵfNn820;D3M9V& |Tv|x+غա'/"+1_~\~,.N=
yokF;<qB*%c2XzG#eY54G[ZjFes[P|YmԐ
.

pc tTrlH(ŕcR*mJNJX>Yug㩊*k{~pTڞU[;4[[x^~^3S|,kbA㡃oA@m@@$_wOJH'UUu]r/[[q,)=cdL᥸KE#º&A!s
t+hVBf0e
u{8Vy<֪>y
pXT;)윒GʎpqAiE3slxZ"嵱) д̩٭qS㡍zzR%%8<Zֺ0v\_{Qt0);
jי伞/=7҈UyWsQ4*	 p6

6TuR
pMj~);+$_[t(#oN,3iNf8< |4ϙ䁩lJm텓hK#񍍵䀋Z1B+O\?r}
=<\9/-/!e\Ȇ*1կt]
w#BMK#~>'k4DGn+-XY_gP+-m9tvEqiIX`@ZjJfvushk
n/C/:TC<,)q1-x"cu::0ݽ3偣|_rDTAlHP#CaГɺڢ1`Cpp4X7X3e}3D!C`$!Yy)8:|q>-bbzT2^?X+VTISY_ TIPUDIBQGL@+4dB"F_ztwP==[j2o37HK
f
aDlxiN:rbe6	XY|ĘAy9cG!ЪOS/,	&2$,\d82rC >ڵxˣ9>}U툪ޘ]V/*w
(ƳaYadUC4LW߉EDm	j#lTGM<_rVԼݾ΢Ǧе+cLٱԺ^~dFjX{
-Vuyv_^EwwȻ)kXyYys/.J{:o:r,~~l}zY]ޮD,)]\p82
-vTk/`Bl؃::gtǚc[7g2J5)"?-N:0쌅~K_]xj/0
(֢ǿs#
zv\ǳ֮}McǖrzQaOZsç`F"l  -o58fd-( *.\9J>Q#F`ٍ
, `CwCξ̠^vRP(h,T\wkh}@Bdx⚳K(>F"6J`x|	6#C~@$"B*YyKa		=+TDdLڪͱ#n]ecf|3Q"V7TFb94333m|B*:syUŧ00	%__eNCO	qY?P"c
y}h߰ٶꎟ
